#
# spec file for package stoken
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         soname libstoken1

Name:           stoken
Version:        0.81
Release:        150400.11.7
Summary:        Token code generator compatible with RSA SecurID 128-bit (AES) token
License:        LGPL-2.0+ and BSD-3-Clause
Group:          Productivity/Security
Url:            http://%{name}.sf.net
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz.asc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  desktop-file-utils
BuildRequires:  libtomcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(nettle)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Software Token for Linux/UNIX. It's a token code generator compatible with RSA
SecurID 128-bit (AES) tokens. It is a hobbyist project, not affiliated with or
endorsed by RSA Security.

This package contains the command line tool for %{name}.


%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}-%{release}

%description devel
Software Token for Linux/UNIX. It's a token code generator compatible with RSA
SecurID 128-bit (AES) tokens. It is a hobbyist project, not affiliated with or
endorsed by RSA Security.

This package provides the development files for %{name}.

%package -n %{soname}
Summary:        Libraries for %{name}
Group:          System/Libraries

%description -n %{soname}
Software Token for Linux/UNIX. It's a token code generator compatible with RSA
SecurID 128-bit (AES) tokens. It is a hobbyist project, not affiliated with or
endorsed by RSA Security.

This package contains %{name} libraries.

%package gui
Summary:        Graphical interface program for %{name}
Group:          Productivity/Security
Requires:       %{soname} = %{version}-%{release}

%description gui
Software Token for Linux/UNIX. It's a token code generator compatible with RSA
SecurID 128-bit (AES) tokens. It is a hobbyist project, not affiliated with or
endorsed by RSA Security.

This package contains the graphical interface program for %{name}.

%prep
%setup -q

%build
autoreconf -v -f --install
%configure --with-gtk --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}-gui.desktop

# Remove stuff we don't need
find %{buildroot} -type f -name "*.la" -delete
#find %{buildroot} -type f -name "*.a" -delete
rm -fr %{buildroot}%{_datarootdir}/doc/%{name}

%post -n %{soname} -p /sbin/ldconfig

%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%defattr(-,root,root,-)
%doc CHANGES COPYING.LIB README.md TODO
%{_libdir}/*.so.*

%files
%defattr(-,root,root,-)
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.gz

%files gui
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}-gui.desktop
%{_datadir}/applications/%{name}-gui-small.desktop
%{_datadir}/%{name}/*.ui
%{_datadir}/pixmaps/%{name}-gui.png
%{_mandir}/man1/%{name}-gui.1.gz

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Mar 26 2015 p.drouand@gmail.com
- Update to version 0.81
  * Fix "make check" failures in GMT+xx timezones (xx >= 1)
- Changes from version 0.8
  * Update GUI from GTK+2 to GTK+3; use glade to define the layouts
  * Add next tokencode and other information to the full GUI (stoken-gui).
    The "stoken-gui --small" layout is unchanged.
  * Add a list of known GUIDs used to bind tokens to specific device classes
    (i.e. tokens can be bound to "any BlackBerry 10").  stoken will now try
    each one of these IDs when importing a new bound token.
  * Add new --qr and --show-qr export options to make it easy to pass tokens
    to a mobile device
  * Add "stoken --next" option to show the next tokencode
  * Support using nettle+gmp as an alternative to libtomcrypt
  * Generate valid TKNTrailer BatchSignature sections in .sdtid output files,
    allowing use with RSA's official TokenConverter utility
  * Fix parsing of RSA-supplied hard token seed files
  * Add "make check" and several test cases
  * Fix build errors on Mac OSX, enable OSX Travis builds, and submit a
    Homebrew formula
  * Fix build errors when using uClibc instead of glibc
  * Add experimental Windows build using MinGW (see README for instructions)
  * Relicense the JNI wrapper (BSD-3-clause) so that it is easier to incorporate
    into non-free Android apps
  * Various fixes for minor bugs, memory leaks, etc.
- Replace pkgconfig(gtk+-2.0) require with pkgconfig(gtk+-3.0);
  follow upstream changes
- Fix license to LGPL-2.0+ and BSD-3-Clause; upstream has relicensed
  the JNI wrapper
- Add pkgconfig(nettle) require; new upstream dependency
- Add CHANGES and TODO to copied documentation list
* Tue Jul 15 2014 darin@darins.net
- define BuildRoot
- add Group for all packages
- add --disable-static to %%configure
* Thu Jul  3 2014 darin@darins.net
- fix libtomcrypt dep due to rename
* Thu Jul  3 2014 darin@darins.net
- set deps to libtomcrypt0 which is the correct package name
* Thu Jun 26 2014 darin@darins.net
- fix requires
* Thu Jun 26 2014 darin@darins.net
- Initial inclusion in openSUSE
  * Ported .spec from Fedora
* Mon Jun 23 2014 negativo17@gmail.com
- Update to 0.6.
* Sun Jun  8 2014 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild
* Mon Mar 17 2014 negativo17@gmail.com
- Update to 0.5.
- Removed upstreamed patch.
* Sun Aug  4 2013 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild
* Wed Jun  5 2013 negativo17@gmail.com
- Change gtk and libtomcrypt build requirements.
- Remove useless "--with-libtomcrypt" parameter from %%%%configure.
* Tue Jun  4 2013 negativo17@gmail.com
- Add patch to avoid static CFLAGS.
- Require proper libtomcrypt version.
* Mon Jun  3 2013 negativo17@gmail.com
- First build.
